@@ -55,9 +55,9 @@ class DatabaseWrapper(BaseDatabaseWrapper):
     Database = pyodbc
 
     DRIVER_MAP = {
-        'DARWIN': '/Applications/GBS/gbasedbt/lib/cli/iclit09b.dylib',
+        'DARWIN': '/Applications/gbasedbt/lib/cli/iclit09b.dylib',
         'LINUX': '/opt/gbase/lib/cli/iclit09b.so',
-        'WINDOWS32bit': 'GBase ODBC DRIVER',
+        'WINDOWS32bit': 'GBase ODBC DRIVER (32-bit)',
         'WINDOWS64bit': 'GBase ODBC DRIVER (64-bit)',
     }
 
@@ -156,7 +156,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         self._validation_enabled = options.get("VALIDATE_CONNECTION", False)
         self._validation_interval = options.get("VALIDATION_INTERVAL", 300)
         self._next_validation = time.time() + self._validation_interval
-        self._validation_query = options.get("VALIDATION_QUERY", "SELECT 1 FROM dual")
+        self._validation_query = options.get("VALIDATION_QUERY", "SELECT 1 FROM DUAL")
         self.encodings = options.get('encodings', ('utf-8', 'cp1252', 'iso-8859-1'))
         # make lookup operators to be collation-sensitive if needed
         self.collation = options.get('collation', None)
@@ -219,7 +219,8 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         if 'DRIVER' not in options or options['DRIVER'] is None:
             options['DRIVER'] = self.get_driver_path()
         if platform.system().upper() != 'WINDOWS':
-            sqlhosts = os.environ.get('GBASEDBTSQLHOSTS')
+            csdkdir = os.environ.get('GBASEDBTDIR','/opt/gbase')
+            sqlhosts = os.environ.get('GBASEDBTSQLHOSTS', f'{csdkdir}/etc/sqlhosts')
             if not sqlhosts or not os.path.exists(sqlhosts):
                 raise ImproperlyConfigured('Cannot find GBase 8s sqlhosts at {}'.format(sqlhosts))
             if not os.path.exists(options['DRIVER']):
@@ -335,7 +336,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         return decoder(self._unescape(raw), self.encodings)
 
     def handle_sql_infx_bigint_as_bigint(self, value):
-        return int.from_bytes(value, byteorder='little', signed=False) 
+        return int.from_bytes(value, byteorder='little', signed=False)
 
     def init_connection_state(self):
         pass
