@@ -7,7 +7,7 @@ class DatabaseCreation(BaseDatabaseCreation):
     def sql_table_creation_suffix(self):
         test_settings = self.connection.settings_dict['TEST']
         assert test_settings['COLLATION'] is None, (
-            "GBasedbt does not support collation setting at database creation time."
+            "GBase 8s does not support collation setting at database creation time."
         )
         if test_settings['CHARSET']:
             return "WITH ENCODING '%s'" % test_settings['CHARSET']
