@@ -9,10 +9,13 @@ EXCLUDED_TABLES = [
     'syscolattribs',
     'syscolauth',
     'syscolcomments',
+    'syscolcomms',
     'syscoldepend',
     'syscolumns',
     'syscolumnsext',
+    'syscommauth',
     'syscomments',
+    'syscomms',
     'sysconstraints',
     'sysdefaults',
     'sysdepend',
